@@ -903,7 +903,7 @@ read_max_control_transfer (MbimDevice *self)
 {
     static const guint8 mbim_signature[4] = { 0x0c, 0x24, 0x1b, 0x00 };
     guint16 max = MAX_CONTROL_TRANSFER;
-    gchar *descriptors_path;
+    gchar *descriptors_path = NULL;
     GError *error = NULL;
     gchar *contents = NULL;
     gsize length = 0;
@@ -950,6 +950,7 @@ read_max_control_transfer (MbimDevice *self)
 
 out:
     g_free (contents);
+    g_free (descriptors_path);
 
     return max;
 }
@@ -1067,6 +1068,13 @@ wait_for_proxy_cb (CreateIoChannelContext *ctx)
     return FALSE;
 }
 
+static void
+spawn_child_setup (void)
+{
+    if (setpgid (0, 0) < 0)
+        g_warning ("couldn't setup proxy specific process group");
+}
+
 static void
 create_iochannel_with_socket (CreateIoChannelContext *ctx)
 {
@@ -1124,7 +1132,7 @@ create_iochannel_with_socket (CreateIoChannelContext *ctx)
                             argc,
                             NULL, /* envp */
                             G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
-                            NULL, /* child_setup */
+                            (GSpawnChildSetupFunc) spawn_child_setup,
                             NULL, /* child_setup_user_data */
                             NULL,
                             &error)) {
