@@ -25,8 +25,10 @@
 #include <string.h>
 #include <stdint.h>
 #include <stdio.h>
+#include <pwd.h>
 
 #include "mbim-utils.h"
+#include "mbim-error-types.h"
 
 /**
  * SECTION:mbim-utils
@@ -72,6 +74,45 @@ __mbim_utils_str_hex (gconstpointer mem,
     return new_str;
 }
 
+/*****************************************************************************/
+gboolean
+__mbim_user_allowed (uid_t uid,
+                     GError **error)
+{
+#ifndef MBIM_USERNAME_ENABLED
+    if (uid == 0)
+        return TRUE;
+#else
+# ifndef MBIM_USERNAME
+#  error MBIM username not defined
+# endif
+
+    struct passwd *expected_usr = NULL;
+
+    /* Root user is always allowed, regardless of the specified MBIM_USERNAME */
+    if (uid == 0)
+        return TRUE;
+
+    expected_usr = getpwnam (MBIM_USERNAME);
+    if (!expected_usr) {
+        g_set_error (error,
+                     MBIM_CORE_ERROR,
+                     MBIM_CORE_ERROR_FAILED,
+                     "Not enough privileges (unknown username %s)", MBIM_USERNAME);
+        return FALSE;
+    }
+
+    if (uid == expected_usr->pw_uid)
+        return TRUE;
+#endif
+
+    g_set_error (error,
+                 MBIM_CORE_ERROR,
+                 MBIM_CORE_ERROR_FAILED,
+                 "Not enough privileges");
+    return FALSE;
+}
+
 /*****************************************************************************/
 
 static volatile gint __traces_enabled = FALSE;
