@@ -100,8 +100,8 @@ signals_handler (int signum)
             g_printerr ("%s\n",
                         "cancelling the operation...\n");
             g_cancellable_cancel (cancellable);
+            return;
         }
-        return;
     }
 
     if (loop &&
@@ -372,7 +372,9 @@ int main (int argc, char **argv)
 
     setlocale (LC_ALL, "");
 
+#if !GLIB_CHECK_VERSION (2, 36, 0)
     g_type_init ();
+#endif
 
     /* Setup option context, process it and destroy it */
     context = g_option_context_new ("- Control MBIM devices");
